pub struct Topic { /* private fields */ }Expand description
Represents a topic with multiple partitions
Implementations
Sourceimpl Topic
impl Topic
Sourcepub async fn new(
config: &Config,
name: String,
num_partitions: u32,
) -> Result<Self>
pub async fn new( config: &Config, name: String, num_partitions: u32, ) -> Result<Self>
Create a new topic with the specified number of partitions
Sourcepub async fn new_with_tiered_storage(
config: &Config,
name: String,
num_partitions: u32,
tiered_storage: Option<Arc<TieredStorage>>,
) -> Result<Self>
pub async fn new_with_tiered_storage( config: &Config, name: String, num_partitions: u32, tiered_storage: Option<Arc<TieredStorage>>, ) -> Result<Self>
Create a new topic with the specified number of partitions and optional tiered storage
Sourcepub fn num_partitions(&self) -> usize
pub fn num_partitions(&self) -> usize
Get the number of partitions
Sourcepub async fn append(&self, partition_id: u32, message: Message) -> Result<u64>
pub async fn append(&self, partition_id: u32, message: Message) -> Result<u64>
Append a message to a specific partition
Sourcepub async fn read(
&self,
partition_id: u32,
start_offset: u64,
max_messages: usize,
) -> Result<Vec<Message>>
pub async fn read( &self, partition_id: u32, start_offset: u64, max_messages: usize, ) -> Result<Vec<Message>>
Read messages from a specific partition
Sourcepub fn all_partitions(&self) -> Vec<Arc<Partition>>
pub fn all_partitions(&self) -> Vec<Arc<Partition>>
Get all partitions
Sourcepub async fn find_offset_for_timestamp(
&self,
partition_id: u32,
target_timestamp: i64,
) -> Result<Option<u64>>
pub async fn find_offset_for_timestamp( &self, partition_id: u32, target_timestamp: i64, ) -> Result<Option<u64>>
Find the first offset with timestamp >= target_timestamp (milliseconds since epoch) Returns None if no matching offset is found.
Sourcepub async fn add_partitions(
&self,
config: &Config,
new_total: u32,
tiered_storage: Option<Arc<TieredStorage>>,
) -> Result<u32>
pub async fn add_partitions( &self, config: &Config, new_total: u32, tiered_storage: Option<Arc<TieredStorage>>, ) -> Result<u32>
Dynamically add partitions to this topic.
Creates new partitions with IDs from current_count to new_total - 1.
Existing partitions and their data are unaffected.