pub struct AbortedTransaction {
pub producer_id: ProducerId,
pub first_offset: u64,
pub last_offset: u64,
}Expand description
Record of an aborted transaction for consumer filtering
Fields
producer_id: ProducerIdProducer ID that aborted
first_offset: u64First offset of the aborted transaction in this partition
last_offset: u64Last offset of the aborted transaction in this partition (inclusive).
Without an upper bound, is_aborted returns true for all
offsets >= first_offset, incorrectly filtering committed messages from
the same producer in later transactions.